from datetime import datetime
from typing import Optional

from pydantic import BaseModel

# Base Todo Schema (shared properties)
class TodoBase(BaseModel):
    title: str
    description: Optional[str] = None
    completed: bool = False

# Schema for creating a Todo
class TodoCreate(TodoBase):
    pass

# Schema for updating a Todo
class TodoUpdate(BaseModel):
    title: Optional[str] = None
    description: Optional[str] = None
    completed: Optional[bool] = None

# Schema for reading a Todo (returned to clients)
class TodoResponse(TodoBase):
    id: int
    created_at: datetime
    updated_at: datetime

    class Config:
        from_attributes = True